
local L = LibStub("AceLocale-3.0"):GetLocale("LAR", true)
local fmt = string.format

LAR = {}
LAR.last_args = {}
LAR.ticker = nil
LAR.listing_failed_count = 0

function LFGListEntryCreation_ListGroup(self)	
	local name = LFGListEntryCreation_GetSanitizedName(self);
	local iLevel = tonumber(self.ItemLevel.EditBox:GetText()) or 0;
	local honorLevel = tonumber(self.HonorLevel.EditBox:GetText()) or 0;
	
	LAR.last_args = {self.selectedActivity, name, iLevel, honorLevel, self.VoiceChat.EditBox:GetText(), self.Description.EditBox:GetText(), LAR.auto_accept_cb:GetChecked()}
	
	if ( LFGListEntryCreation_IsEditMode(self) ) then	
		
		LAR.setup_ticker( LAR.auto_relist_cb:GetChecked() )
		
		C_LFGList.UpdateListing( unpack(LAR.last_args) );
		LFGListFrame_SetActivePanel(self:GetParent(), self:GetParent().ApplicationViewer);
	else
		
		if(C_LFGList.CreateListing( unpack(LAR.last_args) )) then
			LAR.setup_ticker( LAR.auto_relist_cb:GetChecked() )
		
			self.WorkingCover:Show();
			LFGListEntryCreation_ClearFocus(self);
		end
	end
end

LAR.TICKER_DELAY = 5
LAR.ATTEMPTS_LIMIT = 5

function LAR.ticker_OnTick()	
	local listed = C_LFGList.GetActiveEntryInfo()
	
	-- print("LAR.ticker_OnTick(): listed == " .. tostring(listed))
	
	if LAR.listing_failed_count >= LAR.ATTEMPTS_LIMIT then
	print( fmt( L["RELIST_LIMIT_ERROR"], LAR.listing_failed_count ) )
		LAR.setup_ticker(false)
	end
	
	if not listed then
		if not C_LFGList.CreateListing( unpack(LAR.last_args) ) then
			LAR.listing_failed_count = LAR.listing_failed_count + 1
		else
			LAR.listing_failed_count = 0
		end
	end
end

function LAR.setup_ticker( flag )
	-- print("LAR.setup_ticker("..tostring(flag).."): LAR.ticker == "..tostring(LAR.ticker))
	
	if flag then
		if not LAR.ticker then		
			LAR.ticker = C_Timer.NewTicker(LAR.TICKER_DELAY, LAR.ticker_OnTick)
			LAR.listing_failed_count = 0
			
			LAR.stop_auto_relisting_b:Show()
		end
	else
		if LAR.ticker then		
			LAR.ticker:Cancel()
			
			LAR.ticker = nil
			LAR.listing_failed_count = 0
			
			LAR.stop_auto_relisting_b:Hide()
		end
	end
end


-- GUI

LAR.cb_group_frame = CreateFrame("Frame", nil, LFGListFrame.EntryCreation)
LAR.cb_group_frame:SetSize(296, 22)
LAR.cb_group_frame:SetPoint("TOP", LFGListFrame.EntryCreation.VoiceChat, "BOTTOM", 0, -5)

LAR.auto_accept_cb = CreateFrame("CheckButton", nil, LAR.cb_group_frame, "UICheckButtonTemplate")
LAR.auto_relist_cb = CreateFrame("CheckButton", nil, LAR.cb_group_frame, "UICheckButtonTemplate")
LAR.stop_auto_relisting_b = CreateFrame("Button", nil, LFGListFrame, "UIPanelButtonTemplate")

LAR.auto_accept_cb:SetPoint("LEFT", 0, 0)
LAR.auto_accept_cb:SetSize(22,22)
LAR.auto_accept_cb.text:SetText( L[" Auto Accept"] )
LAR.auto_accept_cb.text:SetTextColor(1, 1, 1, 1)
LAR.auto_accept_cb:SetScript("OnShow",
	function (...)
		local active, activityID, ilvl, honorLevel, name, comment, voiceChat, duration, autoAccept = C_LFGList.GetActiveEntryInfo();
		
		LAR.auto_accept_cb:SetChecked( autoAccept or false )
	end
)

LAR.auto_relist_cb:SetPoint("LEFT", 158, 0)
LAR.auto_relist_cb:SetSize(22,22)
LAR.auto_relist_cb.text:SetText( L[" Auto Relist"] )
LAR.auto_relist_cb.text:SetTextColor(1, 1, 1, 1)

LAR.stop_auto_relisting_b:SetPoint("RIGHT", LFGListFrame.CategorySelection.StartGroupButton, "LEFT", -40, 0)
LAR.stop_auto_relisting_b:SetSize(140,22)
LAR.stop_auto_relisting_b:SetText( L["Stop AutoRelisting"] )
LAR.stop_auto_relisting_b:SetScript("OnClick", function (...) LAR.setup_ticker( false ) end)
LAR.stop_auto_relisting_b:Hide()

-- Hooks

LFGListFrame.ApplicationViewer.AutoAcceptButton:HookScript(
	"OnClick",
	function (...)
		local auto_accept = LFGListFrame.ApplicationViewer.AutoAcceptButton:GetChecked();
		--LAR.auto_accept_cb:SetChecked( auto_accept )
		LAR.last_args[7] = auto_accept;
	end
)

LAR.old_LFGListRequirement_Validate = LFGListRequirement_Validate

LFGListRequirement_Validate = function(...)
	
	local ec = LFGListFrame.EntryCreation
	local ilvl = ec.ItemLevel
	local hlvl = ec.HonorLevel
	local vc = ec.VoiceChat	
	
	if hlvl:IsShown() then
		hlvl:ClearAllPoints()
		hlvl:SetMovable(true)
		hlvl:SetPoint("TOP", ilvl, "BOTTOM", 0, 3)

		vc:ClearAllPoints()
		vc:SetMovable(true)
		vc:SetPoint("TOP", hlvl, "BOTTOM", 0, 3)
		
		LAR.cb_group_frame:ClearAllPoints()
		LAR.cb_group_frame:SetPoint("TOP", vc, "BOTTOM", 0, 3)
	else
		vc:ClearAllPoints()
		vc:SetMovable(true)
		vc:SetPoint("TOP", ilvl, "BOTTOM", 0, -5)
		
		LAR.cb_group_frame:ClearAllPoints()
		LAR.cb_group_frame:SetPoint("TOP", vc, "BOTTOM", 0, -5)
	end
	
	LAR.old_LFGListRequirement_Validate(...)
end